@@ -29,8 +29,7 @@ describe 'mysql::server::backup class' do
         }
     MANIFEST
     it 'when configuring mysql backups' do
-      apply_manifest(pp, catch_failures: true)
-      apply_manifest(pp, catch_failures: true)
+      idempotent_apply(default, pp, {})
     end
   end
 
@@ -104,8 +103,7 @@ describe 'mysql::server::backup class' do
           }
       MANIFEST
       it 'when configuring mysql backups' do
-        apply_manifest(pp, catch_failures: true)
-        apply_manifest(pp, catch_failures: true)
+        idempotent_apply(default, pp, {})
       end
     end
 
@@ -124,7 +122,7 @@ describe 'mysql::server::backup class' do
 
       it 'creates one file per database' do
         unless version_is_greater_than('5.7.0')
-          %w[backup1 backup2].each do |database|
+          ['backup1', 'backup2'].each do |database|
             shell("ls -l /tmp/backups/mysql_backup_#{database}_*-*.sql.bz2 | wc -l") do |r|
               expect(r.stdout).to match(%r{1})
               expect(r.exit_code).to be_zero
@@ -142,7 +140,7 @@ describe 'mysql::server::backup class' do
 
       it 'has one file per database per run' do
         unless version_is_greater_than('5.7.0')
-          %w[backup1 backup2].each do |database|
+          ['backup1', 'backup2'].each do |database|
             shell("ls -l /tmp/backups/mysql_backup_#{database}_*-*.sql.bz2 | wc -l") do |r|
               expect(r.stdout).to match(%r{2})
               expect(r.exit_code).to be_zero
@@ -153,50 +151,4 @@ describe 'mysql::server::backup class' do
       # rubocop:enable RSpec/MultipleExpectations, RSpec/ExampleLength
     end
   end
-
-  context 'with triggers and routines' do
-    pre_run
-    pp = <<-MANIFEST
-        class { 'mysql::server': root_password => 'password' }
-        mysql::db { [
-          'backup1',
-          'backup2'
-          ]:
-          user => 'backup',
-          password => 'secret',
-        }
-        package { 'bzip2':
-          ensure => present,
-        }
-        class { 'mysql::server::backup':
-          backupuser => 'myuser',
-          backuppassword => 'mypassword',
-          backupdir => '/tmp/backups',
-          backupcompress => true,
-          file_per_database => true,
-          include_triggers => #{version_is_greater_than('5.1.5')},
-          include_routines => true,
-          postscript => [
-            'rm -rf /var/tmp/mysqlbackups',
-            'rm -f /var/tmp/mysqlbackups.done',
-            'cp -r /tmp/backups /var/tmp/mysqlbackups',
-            'touch /var/tmp/mysqlbackups.done',
-          ],
-          execpath => '/usr/bin:/usr/sbin:/bin:/sbin:/opt/zimbra/bin',
-          require => Package['bzip2'],
-        }
-    MANIFEST
-    it 'when configuring mysql backups with triggers and routines' do
-      apply_manifest(pp, catch_failures: true)
-    end
-
-    it 'runs mysqlbackup.sh with no errors' do
-      pre_run
-      unless version_is_greater_than('5.7.0')
-        shell('/usr/local/sbin/mysqlbackup.sh') do |r|
-          expect(r.stderr).to eq('')
-        end
-      end
-    end
-  end
 end
