@@ -4,30 +4,19 @@ require 'spec_helper_acceptance'
 # of mysql) have varying levels of support for plugins and have
 # different plugins available. Choose a plugin that works or don't try
 # to test plugins if not available.
-if fact('osfamily') =~ %r{RedHat}
-  if fact('operatingsystemrelease') =~ %r{^5\.}
+if fact('osfamily') == 'redhat'
+  if os[:release].to_i == 5
     plugin = nil # Plugins not supported on mysql on RHEL 5
-  elsif fact('operatingsystemrelease') =~ %r{^6\.}
+  elsif os[:release].to_i == 6
     plugin     = 'example'
     plugin_lib = 'ha_example.so'
-  elsif fact('operatingsystemrelease') =~ %r{^7\.}
+  elsif os[:release].to_i == 7
     plugin     = 'pam'
     plugin_lib = 'auth_pam.so'
   end
-elsif fact('osfamily') =~ %r{Debian}
-  if fact('operatingsystem') =~ %r{Debian}
-    if fact('operatingsystemrelease') =~ %r{^6\.}
-      # Only available plugin is innodb which is already loaded and not unload- or reload-able
-      plugin = nil
-    elsif fact('operatingsystemrelease') =~ %r{^7\.}
-      plugin     = 'example'
-      plugin_lib = 'ha_example.so'
-    end
-  elsif fact('operatingsystem') =~ %r{Ubuntu}
-    if fact('operatingsystemrelease') =~ %r{^10\.04}
-      # Only available plugin is innodb which is already loaded and not unload- or reload-able
-      plugin = nil
-    elsif fact('operatingsystemrelease') =~ %r{^16\.04}
+elsif fact('osfamily') == 'debian'
+  if os[:family] == 'ubuntu'
+    if os[:release] =~ %r{^16\.04|^18\.04}
       # On Xenial running 5.7.12, the example plugin does not appear to be available.
       plugin = 'validate_password'
       plugin_lib = 'validate_password.so'
@@ -36,7 +25,7 @@ elsif fact('osfamily') =~ %r{Debian}
       plugin_lib = 'ha_example.so'
     end
   end
-elsif fact('osfamily') =~ %r{Suse}
+elsif fact('osfamily') == 'suse'
   plugin = nil # Plugin library path is broken on Suse http://lists.opensuse.org/opensuse-bugs/2013-08/msg01123.html
 end
 
@@ -48,7 +37,7 @@ describe 'mysql_plugin' do
           class { 'mysql::server': }
         MANIFEST
 
-        apply_manifest(pp, catch_failures: true)
+        execute_manifest(pp, catch_failures: true)
       end
     end
 
@@ -60,7 +49,7 @@ describe 'mysql_plugin' do
           }
       MANIFEST
       it 'works without errors' do
-        apply_manifest(pp, catch_failures: true)
+        execute_manifest(pp, catch_failures: true)
       end
 
       it 'finds the plugin #stdout' do
