@@ -363,7 +363,7 @@ describe 'mysql::server::backup' do
 
         it 'contains the wrapper script' do
           is_expected.to contain_file('xtrabackup.sh').with_content(
-            %r{^innobackupex\s+.*?"\$@"},
+            %r{(\n*^xtrabackup\s+.*\$@)},
           )
         end
 
@@ -398,6 +398,18 @@ describe 'mysql::server::backup' do
             )
           end
         end
+        context 'with mariabackup' do
+          let(:params) do
+            default_params.merge(provider: 'xtrabackup',
+                                 backupmethod: 'mariabackup')
+          end
+
+          it 'contain the mariabackup executor' do
+            is_expected.to contain_file('xtrabackup.sh').with_content(
+              %r{(\n*^mariabackup\s+.*\$@)},
+            )
+          end
+        end
       end
     end
   end
