@@ -10,8 +10,9 @@ describe 'mysql::db', type: :define do
       let(:title) { 'test_db' }
 
       let(:params) do
-        { 'user'     => 'testuser',
-          'password' => 'testpass' }
+        { 'user'            => 'testuser',
+          'password'        => 'testpass',
+          'mysql_exec_path' => '' }
       end
 
       it 'does not notify the import sql exec if no sql script was provided' do
@@ -20,6 +21,7 @@ describe 'mysql::db', type: :define do
 
       it 'subscribes to database if sql script is given' do
         params['sql'] = 'test_sql'
+        is_expected.to contain_mysql_database('test_db')
         is_expected.to contain_exec('test_db-import').with_subscribe('Mysql_database[test_db]')
       end
 
@@ -28,35 +30,30 @@ describe 'mysql::db', type: :define do
         is_expected.to contain_exec('test_db-import').with_refreshonly(true)
       end
 
-      it 'imports sql script on creation if enforcing #refreshonly' do
+      it 'imports sql script on creation' do
         params.merge!('sql' => 'test_sql', 'enforce_sql' => true)
+        # ' if enforcing #refreshonly'
         is_expected.to contain_exec('test_db-import').with_refreshonly(false)
-      end
-      it 'imports sql script on creation if enforcing #command' do
-        params.merge!('sql' => 'test_sql', 'enforce_sql' => true)
+        # 'if enforcing #command'
         is_expected.to contain_exec('test_db-import').with_command('cat test_sql | mysql test_db')
       end
 
-      it 'imports sql script with custom command on creation if enforcing #refreshonly' do
+      it 'imports sql script with custom command on creation ' do
         params.merge!('sql' => 'test_sql', 'enforce_sql' => true, 'import_cat_cmd' => 'zcat')
+        # if enforcing #refreshonly
         is_expected.to contain_exec('test_db-import').with_refreshonly(false)
-      end
-      it 'imports sql script with custom command on creation if enforcing #command' do
-        params.merge!('sql' => 'test_sql', 'enforce_sql' => true, 'import_cat_cmd' => 'zcat')
+        # if enforcing #command
         is_expected.to contain_exec('test_db-import').with_command('zcat test_sql | mysql test_db')
       end
 
       it 'imports sql scripts when more than one is specified' do
-        params['sql'] = %w[test_sql test_2_sql]
+        params['sql'] = ['test_sql', 'test_2_sql']
         is_expected.to contain_exec('test_db-import').with_command('cat test_sql test_2_sql | mysql test_db')
       end
 
       it 'does not create database' do
         params.merge!('ensure' => 'absent', 'host' => 'localhost')
         is_expected.to contain_mysql_database('test_db').with_ensure('absent')
-      end
-      it 'does not create database user' do
-        params.merge!('ensure' => 'absent', 'host' => 'localhost')
         is_expected.to contain_mysql_user('testuser@localhost').with_ensure('absent')
       end
 
@@ -70,6 +67,16 @@ describe 'mysql::db', type: :define do
         params['dbname'] = 'real_db'
         is_expected.to contain_mysql_database('real_db')
       end
+
+      it 'uses tls_options for user when set' do
+        params['tls_options'] = ['SSL']
+        is_expected.to contain_mysql_user('testuser@localhost').with_tls_options(['SSL'])
+      end
+
+      it 'uses grant_options for grant when set' do
+        params['grant_options'] = ['GRANT']
+        is_expected.to contain_mysql_grant('testuser@localhost/test_db.*').with_options(['GRANT'])
+      end
     end
   end
 end
