@@ -52,7 +52,6 @@ describe Puppet::Type.type(:mysql_user).provider(:mysql) do
   let(:newhash) { '*6C8989366EAF75BB670AD8EA7A7FC1176A95CEF5' }
 
   let(:raw_users) do
-    # rubocop:disable Layout/IndentHeredoc
     <<-SQL_OUTPUT
 root@127.0.0.1
 root@::1
@@ -65,7 +64,7 @@ usvn_user@localhost
     # rubocop:enable Layout/IndentHeredoc
   end
 
-  let(:parsed_users) { %w[root@127.0.0.1 root@::1 @localhost debian-sys-maint@localhost root@localhost usvn_user@localhost @vagrant-ubuntu-raring-64] }
+  let(:parsed_users) { ['root@127.0.0.1', 'root@::1', '@localhost', 'debian-sys-maint@localhost', 'root@localhost', 'usvn_user@localhost', '@vagrant-ubuntu-raring-64'] }
   let(:provider) { resource.provider }
   let(:instance) { provider.class.instances.first }
   let(:resource) do
@@ -175,6 +174,15 @@ usvn_user@localhost
       provider.expects(:exists?).returns(true)
       expect(provider.create).to be_truthy
     end
+    it 'creates a user using IF NOT EXISTS' do
+      provider.class.instance_variable_set(:@mysqld_version_string, '5.7.6')
+
+      provider.class.expects(:mysql_caller).with("CREATE USER IF NOT EXISTS 'joe'@'localhost' IDENTIFIED WITH 'mysql_native_password' AS '*6C8989366EAF75BB670AD8EA7A7FC1176A95CEF4'", 'system') # rubocop:disable Metrics/LineLength
+      provider.class.expects(:mysql_caller).with("ALTER USER IF EXISTS 'joe'@'localhost' WITH MAX_USER_CONNECTIONS 10 MAX_CONNECTIONS_PER_HOUR 10 MAX_QUERIES_PER_HOUR 10 MAX_UPDATES_PER_HOUR 10", 'system') # rubocop:disable Metrics/LineLength
+      provider.class.expects(:mysql_caller).with("ALTER USER 'joe'@'localhost' REQUIRE NONE", 'system')
+      provider.expects(:exists?).returns(true)
+      expect(provider.create).to be_truthy
+    end
   end
 
   describe 'destroy' do
@@ -183,6 +191,12 @@ usvn_user@localhost
       provider.expects(:exists?).returns(false)
       expect(provider.destroy).to be_truthy
     end
+    it 'removes a user using IF EXISTS' do
+      provider.class.instance_variable_set(:@mysqld_version_string, '5.7.1')
+
+      provider.class.expects(:mysql_caller).with("DROP USER IF EXISTS 'joe'@'localhost'", 'system')
+      expect(provider.destroy).to be_truthy
+    end
   end
 
   describe 'exists?' do
@@ -362,9 +376,7 @@ usvn_user@localhost
     end
   end
 
-  %w[max_user_connections max_connections_per_hour max_queries_per_hour
-     max_updates_per_hour].each do |property|
-
+  ['max_user_connections', 'max_connections_per_hour', 'max_queries_per_hour', 'max_updates_per_hour'].each do |property|
     describe property do
       it "returns #{property}" do
         expect(instance.send(property.to_s.to_sym)).to eq('10')
